@@ -78,6 +78,16 @@ NWCEntrySelectionState::NWCEntrySelectionState( const NWCEntrySelectionState &ot
     }
 }
 
+NWCEntrySelectionState::NWCEntrySelectionState( const NWC::FSEntry &entry )
+    : m_entry_id( -1 ),
+      m_use( true ),
+      m_filetype( nullptr ),
+      m_colors( FileEntryColor() ),
+      m_selected( false )
+{
+    m_cloned_entry.reset( entry.clone() );
+}
+
 NWCEntrySelectionState &NWCEntrySelectionState::operator=( const NWCEntrySelectionState &rhs )
 {
     if ( this != &rhs ) {
